# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from datetime import datetime
import inspect

from django.conf import settings
from django.utils import six

try:
    from django.contrib.auth import get_user_model
except ImportError:
    from django.contrib.auth.models import User
    get_user_model = lambda: User

try:
    from django.db.transaction import atomic
    commit_on_success = atomic
except ImportError:
    from django.db.transaction import commit_on_success

user_model_label = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')

if six.PY2:
    Base64Error = TypeError
else:
    from binascii import Error as Base64Error

if hasattr(inspect, 'signature'):
    def signature_parameters(func):
        return inspect.signature(func).parameters.keys()
else:
    def signature_parameters(func):
        return inspect.getargspec(func)[0]
